Newt DB Project Contributor Agreement
=====================================

(Adapted from the `Pyramid contributor's agreement
<https://raw.githubusercontent.com/Pylons/pyramid/master/CONTRIBUTORS.txt>`_.)

The submitter agrees by adding his or her name within the section below named
"Contributors" and submitting the resulting modified document to the
canonical shared repository location for this software project (whether
directly, as a user with "direct commit access", or via a "pull request"), he
or she is signing a contract electronically.  The submitter becomes a
Contributor after a) he or she signs this document by adding their name
beneath the "Contributors" section below, and b) the resulting document is
accepted into the canonical version control repository.

Treatment of Account
---------------------

Contributor will not allow anyone other than the Contributor to use his or
her username or source repository login to submit code to the Newt DB Project
source repository. Should Contributor become aware of any such use,
Contributor will immediately notify the Newt DB project managers.
Notification must be performed by sending an email to
contributor@newtdb.org.  Until such notice is received, Contributor will be
presumed to have taken all actions made through Contributor's account. If the
Contributor has direct commit access, the Newt DB project managers will have
complete control and discretion over capabilities assigned to Contributor's
account, and may disable Contributor's account for any reason at any time.

Legal Effect of Contribution
----------------------------

Upon submitting a change or new work to the Newt DB Project source
Repository (a "Contribution"), you agree to assign, and hereby do
assign, a one-half interest of all right, title and interest in and to
copyright and other intellectual property rights with respect to your
new and original portions of the Contribution to the Newt DB
project. You and the Newt DB project each agree that the other shall be
free to exercise any and all exclusive rights in and to the
Contribution, without accounting to one another, including without
limitation, the right to license the Contribution to others under the
MIT License. This agreement shall run with title to the
Contribution. the Newt DB project does not convey to you any right,
title or interest in or to the Program or such portions of the
Contribution that were taken from the Program. Your transmission of a
submission to the Newt DB Project source Repository and marks of
identification concerning the Contribution itself constitute your
intent to contribute and your assignment of the work in accordance
with the provisions of this Agreement.

License Terms
-------------

Code committed to the Newt DB Project source repository (Committed
Code) must be governed by the MIT License,
https://opensource.org/licenses/MIT, or another license acceptable to
the Newt DB project.  Until the Newt DB project declares in writing an
acceptable license other than the MIT License, only the MIT License
shall be used.  A list of exceptions is detailed within the "Licensing
Exceptions" section of this document, if one exists.

Representations, Warranty, and Indemnification
----------------------------------------------

Contributor represents and warrants that the Committed Code does not violate
the rights of any person or entity, and that the Contributor has legal
authority to enter into this Agreement and legal authority over Contributed
Code. Further, Contributor indemnifies the Newt DB project against
violations.

Cryptography
------------

Contributor understands that cryptographic code may be subject to government
regulations with which the Newt DB project and/or entities using Committed
Code must comply. Any code which contains any of the items listed below must
not be checked-in until the Newt DB project staff has been notified and has
approved such contribution in writing.

- Cryptographic capabilities or features

- Calls to cryptographic features

- User interface elements which provide context relating to cryptography

- Code which may, under casual inspection, appear to be cryptographic.

Notices
-------

Contributor confirms that any notices required will be included in any
Committed Code.

Licensing Exceptions
====================

Code committed within the ``docs/`` subdirectory of the Pyramid source
control repository and "docstrings" which appear in the documentation
generated by running "make" within this directory is licensed under the
Creative Commons Attribution-Noncommercial-Share Alike 3.0 United States
License (http://creativecommons.org/licenses/by-nc-sa/3.0/us/).

List of Contributors
====================

The below-signed are contributors to a code repository that is part of the
project named "Newt DB".  Each below-signed contributor has read, understand
and agrees to the terms above in the section within this document entitled
"Newt DB Project Contributor Agreement" as of the date beside his or her name.

Contributors
------------

- Jim Fulton, 2017/01/24
- Jason Madden, 2017/01/25
